@@ -718,6 +718,7 @@ class IPCC_AR6(object):
         'R5OECD90+EU' : 'R5OECD', 
         'R5REF' : 'R5REF',
         'R5ROWO' : 'R5ROWO',
+        'R10ROWO' : 'R10ROWO',
         'R10AFRICA': 'R10AFRICA',
          'R10CHINA+': 'R10CHINA+',
          'R10EUROPE': 'R10EUROPE',
@@ -727,7 +728,8 @@ class IPCC_AR6(object):
          'R10NORTH_AM': 'R10NORTH_AM',
          'R10PAC_OECD': 'R10PAC_OECD',
          'R10REF_ECON': 'R10REF_ECON',
-         'R10REST_ASIA': 'R10REST_ASIA'}
+         'R10REST_ASIA': 'R10REST_ASIA',
+         'R10ROWO': 'R10ROWO'}
         
         
         mapping = pd.DataFrame(mapping.items(), columns = ['native', 'standard'])
