@@ -37,7 +37,9 @@ emission_entities = set([
 #%% Energy (production if not otherwise stated)
 energy_entities = set([
     'Cumulative Capacity', 
+    'Capacity Additions',
     'Capacity',
+    'Capacity|Electricity|Storage Capacity',
     'Capital Cost',
     'Carbon Sequestration',
     'Primary Energy',           # PE
