@@ -78,6 +78,7 @@ def open_word_file(file_name):
     import datatoolbox as dt
     dt.util.open_file(file_name)
     
+
 class Document():
     
     
@@ -86,6 +87,8 @@ class Document():
         self.doc = docx.Document()
         # return self.doc
 
+    def add_page_break(self,):
+        self.doc.add_page_break()
 
     def add_heading(self, string, level):
         self.doc.add_heading(string,level=level)
@@ -99,6 +102,7 @@ class Document():
                   heading, 
                   float_format = '{:2.1f}',
                   ignore_index = False,
+                  ignore_colums = False,
                   style = 'Light List Accent 1'):
         
         if ignore_index:
@@ -116,9 +120,10 @@ class Document():
         cells[0].text = heading
         
         # populate header row --------
-        heading_cells = table.add_row().cells
-        for i, col in enumerate(pandas_table.columns):
-             heading_cells[i+offset].text = str(col)
+        if not ignore_colums:
+            heading_cells = table.add_row().cells
+            for i, col in enumerate(pandas_table.columns):
+                 heading_cells[i+offset].text = str(col)
         # heading_cells[1].0text = 'Oil'
         # heading_cells[2].text = 'Gas'
         # heading_cells[3].text = 'Nuclear'
@@ -225,7 +230,7 @@ class Document():
                         height, 
                         )
         
-        plt.close()
+        #plt.close()
          
         os.remove(path)
         
